.. Sheepdog documentation master file, created by
   sphinx-quickstart on Wed Dec  4 14:46:17 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Sheepdog's documentation!
====================================

Sheepdog effects GridEngine jobs without affecting your affect.

Contents:

.. toctree::
   :maxdepth: 2

   quickstart
   configuration
   changelog
   code/modules



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

